@@ -6,8 +6,8 @@
 from typing import (
     List,
 )
-#from . import dc_utils
-import dc_utils
+from . import dc_utils
+# import dc_utils
 import cmd2
 import argparse
 import os
@@ -304,8 +304,8 @@ def main():
     app = DC()
     app.cmdloop()
 
-if __name__ == "__main__":
-   main()
+# if __name__ == "__main__":
+#    main()
 
 
 
