@@ -3,6 +3,5 @@
 # Copyright (C) 2018-2021 Intel Corporation
 # SPDX-License-Identifier: Apache-2.0
 
-
-sudo rm -rf openvino
-echo -e "\e[1;32mbenchmark-tool with openvino is unistalled\e[0m"
+unlink tools
+echo -e "\e[1;32mOMZ-tools Symbolic link Unlinked\e[0m"
