@@ -12,4 +12,7 @@ fi
 
 #pulling the modelserver image
 sudo docker pull openvino/model_server:latest
-echo -e "\e[1;32mopenvino-modelserver image pulled\e[0m "
+echo -e "\e[1;32mopenvino-modelserver image pulled\e[0m"
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+echo -e "\e[1;32m\nhttps://github.com/openvinotoolkit/model_server\e[0m"
+
