@@ -18,6 +18,22 @@ fi
 
 #installing proxy settings for openvino
 
+if [[ $(echo $http_proxy) || $(echo $https_proxy) ]]; then
+        echo "installing......."
+        sudo chmod 777 /etc/environment
+        sudo echo "http_proxy=http://proxy-dmz.intel.com:911
+        https_proxy=http://proxy-dmz.intel.com:911
+        HTTP_PROXY=http://proxy-dmz.intel.com:911
+        HTTPS_PROXY=http://proxy-dmz.intel.com:91
+        tp_proxy=http://proxy-dmz.com:911
+        NO_PROXY=localhost,127.0.0.1    
+        no_proxy=localhost,127.0.0.1" > /etc/environment
+        source /etc/environment
+else
+
+        echo "proxy setting are done"
+fi
+
 #echo "installing proxy settings for openvino"
 
 #sudo chmod 777 /etc/environment
