@@ -18,6 +18,22 @@ fi
 
 #Installing proxy settings for openvino
 
+if [[ $(echo $http_proxy) || $(echo $https_proxy) ]]; then
+        echo "installing......."
+        sudo chmod 777 /etc/environment
+        sudo echo "http_proxy=http://proxy-dmz.intel.com:911
+        https_proxy=http://proxy-dmz.intel.com:911
+        HTTP_PROXY=http://proxy-dmz.intel.com:911
+        HTTPS_PROXY=http://proxy-dmz.intel.com:91
+        tp_proxy=http://proxy-dmz.com:911
+        NO_PROXY=localhost,127.0.0.1    
+        no_proxy=localhost,127.0.0.1" > /etc/environment
+        source /etc/environment
+else
+
+        echo "proxy setting are done"
+fi
+
 #echo "installing proxy settings for openvino"
 
 #sudo chmod 777 /etc/environment
@@ -40,7 +56,7 @@ echo -e "\e[1;34mThis will take couple of minutes......\e[0m"
 pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 8f4db493-0381-4391-8ec8-2af1b450ad45 | $HOME/.local/bin/edgesoftware install textile-defect-classifier 61703650d8ecccee55019b27
 
-echo -e "\e[1;34mTextile-Defect-Classifier_<version> folder is downloaded in \home\intel\<username>\e[0m\n"
+echo -e "\e[1;34mTextile-Defect-Classifier_<version> folder is downloaded successfully in Workload folder\e[0m\n"
 
 #Check RI is installed sucessfully
 
