@@ -24,12 +24,10 @@ echo -e "\e[1;36m\nThis will take couple of minutes....\e[0m"
 pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 6b90d312-0969-45b6-be28-6f6ac8873d9e | $HOME/.local/bin/edgesoftware install interactive-kiosk-ai-chatbot 62443d3a9654a8f4bd9cbca6
 
-echo "-------------------------------------------------------------------------------------------------------------------------------------\n"
-echo -e "\e[1;34mInteractive-Kiosk-AI-Chatbot<version> folder is downloaded in \home\intel\<<user>>\e[0m\n"
+echo -e "\e[1;34mInteractive-Kiosk-AI-Chatbot<version> folder is downloaded successfully in Workload folder\e[0m\n"
 
 #Checking RI is installed sucessfully
 
 echo -e "\e[1;32m\nIf interactive-kiosk-ai-chatbot RI installed successfully...\e[0m"
 echo -e "\e[1;36mFor further development refer below URL\e[0m"
 echo -e "\e[1;33mhttps://www.intel.com/content/www/us/en/developer/articles/reference-implementation/interactive-kiosk-ai-chatbot.html\e[0m\n"
-echo "-------------------------------------------------------------------------------------------------------------------------------------\n"
