@@ -16,6 +16,7 @@ if [[ $OS_VERSION != "20.04" ]]; then
 
 fi
 
+
 #Installing social-distancing-for-retail-settings
 
 echo "Installing social-distancing-for-retail-settings ..."
@@ -25,10 +26,10 @@ echo -e "\e[1;36mThis will take couple of minutes ......\e[0m"
 pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 0bc6f800-f667-464d-af07-9ad7fc03606b | $HOME/.local/bin/edgesoftware install social-distancing-for-retail-settings 627a09c506338088f3910d81
 
-echo -e "\e[1;34mSocial_Distancing_for_Retail_Settings_<version> folder is downloaded in \home\intel\<<username>>\e[0m\n"
+echo -e "\e[1;34mSocial_Distancing_for_Retail_Settings_<version> folder is downloaded successfully in Workload folder\e[0m\n"
 
 #Check RI is installed sucessfully
 
-echo -e "\e[1;32m\nIf social-distancing-for-retail-settings RI installed suceessfully...\e[0m"
+echo -e "\e[1;32m\nIf social-distancing-for-retail-settings RI installed successfully...\e[0m"
 echo -e "\e[1;36mFor further development refer below URL\e[0m"
 echo -e "\e[1;33mhttps://www.intel.com/content/www/us/en/developer/articles/reference-implementation/social-distancing-for-retail-settings.html\e[0m\n"
